#######################################################
#######################################################
############    COPYRIGHT - DATA SOCIETY   ############
#######################################################
#######################################################

####################################
##   CUSTOMIZING GRAPHS ANSWERS   ##
####################################

## NOTE: To run individual pieces of code, 
## select the line of code and press ctrl + enter for Windows
## and command + enter for Macs

# Your code does not need to match up exactly - these answers
# are examples of how to execute the exercises below, but you may
# have found other ways to get the same output. 

#==================================================================================

# Make sure you have loaded and installed the ggplot2 and plyr packages
# for these exercises. 

install.packages("ggplot2")
install.packages("plyr")

library(ggplot2)
library(plyr)

# HINT: as we build up the code in steps, you can copy and paste the previous
#       code and then add on to it. This will save you time!


# 1. Load the "CaBi data.csv", label it as CaBi.data, and view the data

setwd("path to files")
CaBi.data = read.csv("CaBi data.csv")

View(CaBi.data)

# 2. Plot a scatter plot from CaBi.data with 'Day' as the x axis, 'Duration.min'
#    as the y axis, and 'Time.of.Day as shape and color.

ggplot(CaBi.data, aes(x = Day, 
                           y = Duration.min, 
                           shape = Time.of.Day, 
                           color = Time.of.Day)) + 
  geom_point()

# 3. Plot the same data as a stacked bar chart

ggplot(CaBi.data, 
       aes(x = Day, 
           y = Duration.min, 
           fill = Time.of.Day)) + 
  geom_bar(stat = "identity")

# 4. Reorder the data by 'Time.of.Day' and call the data 'CaBi.data.order'

CaBi.data.order = CaBi.data[order(CaBi.data$Time.of.Day, decreasing = F),]
View(CaBi.data.order)

# 5. Graph CaBi.data.order as a stacked bar chart

ggplot(CaBi.data.order, 
       aes(x = Day, 
           y = Duration.min, 
           fill = Time.of.Day)) + 
  geom_bar(stat = "identity")

# 6. Split the data by Time.of.Day and create a column labeled 'label_y' with
#    the cumulative sum of Duration.min. Label the data as 'CaBi.labels' data set.

CaBi.labels = ddply(CaBi.data.order, 
                              .(Time.of.Day),                 
                              transform,               
                              label_y = cumsum(Duration.min))    
View(CaBi.labels)

# 7. Plot 'CaBi.labels' into the stacked bar chart, and use the geom_text() 
#    function to create labels from the label_y column

ggplot(CaBi.labels, 
       aes(x = Day, 
           y = Duration.min, 
           fill = Time.of.Day)) + 
  geom_bar(stat = "identity") +
  geom_text(aes(y = label_y, label = label_y))

# 8. Since that didn't come out as we wanted, go back and summarize CaBi.labels
#    by 'Day' and 'Time.of.Day'. Sum up 'Duration.min' and label the column as
#    'Total'. Label the data set as CaBi.labels2

CaBi.labels2 = ddply(CaBi.labels,
                     .(Day, Time.of.Day),
                     summarise,
                     Total = sum(Duration.min))
View(CaBi.labels2)

# 9. In order for the labels to be in the right location, we need to add 
#    another column that sums up the 'Total' column by 'Day'. Name that
#    data set 'CaBi.labels3', and label the column 'label_y'.

CaBi.labels3 = ddply(CaBi.labels2, 
                    .(Day),                 
                    transform,               
                    label_y = cumsum(Total))    
View(CaBi.labels3)

# 10. Plot CaBi.labels3 with the labels from the label_y column.

ggplot(CaBi.labels3, 
       aes(x = Day, 
           y = Total, 
           fill = Time.of.Day)) + 
  geom_bar(stat = "identity") +
  geom_text(aes(y = label_y, label = label_y))

# 11. Load in the CaBi.annual data set and view it.

CaBi.annual = read.csv("CaBi.annual.csv")

View(CaBi.annual)

# 12. Plot a stacked area plot with the CaBi.annual data, where the x
#     axis is 'No.Months', the y axis is 'New.Member.Count', and the fill
#     is by 'Municipality'.

ggplot(CaBi.annual, 
       aes(x = No.Months, 
           y = New.Member.Count, 
           fill = Municipality)) + 
  geom_area()

# 13. In order to create a cumulative stacked area plot, we need to add
#     a column with that data. First, we need to sort the data by Municipality
#     and then by year so it will be in the right order. Label this new data
#     as 'CaBi.annual2'

CaBi.annual2 = CaBi.annual[order(CaBi.annual$Municipality, 
                                 CaBi.annual$Year, decreasing = F),]
View(CaBi.annual2)

# 14. Use ddply to add a column that cumulatively adds the New.Member.Count
#     column by Municipality and label the column 'Members'. Name the new
#     data as 'CaBi.annual3'

CaBi.annual3 = ddply(CaBi.annual2, 
                     .(Municipality),                 
                     transform,               
                     Members = cumsum(New.Member.Count))    
View(CaBi.annual3)

# 15. Plot the stacked area chart again with the 'CaBi.annual3' data and the 
#     same variables as Question 12. 

ggplot(CaBi.annual3, 
       aes(x = No.Months, 
           y = Members, 
           fill = Municipality)) + 
  geom_area()


#### Part 2 ####


# Let's graph the area plot by percentage. In order to do that, we need to
# know the total number of new members per month, so we can calculate the
# percent for each municipality.

# 16. Use ddply on 'CaBi.annual3' to summarize 'New.Member.Count' by 'No.Months'.
#     Label the new column as 'Per.Month' and the data set as 'CaBi.pct' and 
#     view the new data set.

CaBi.pct = ddply(CaBi.annual3,
                 .(No.Months),
                 summarize,
                 Per.Month = sum(New.Member.Count))

View(CaBi.pct)

# 17. Next, we can use the join() function to merge 'CaBi.annual3' and 'CaBi.pct'
#     by 'No.Months'. Name this data set as 'CaBi.pct1'.

CaBi.pct1 = join(CaBi.annual3, CaBi.pct, by = "No.Months")
View(CaBi.pct1)

# 18. Add a percentage column called 'Percent' to 'CaBi.pct1' with ddply() 
#     where you divide the 'New.Member.Count' column by the 'Per.Month' column
#     and multiply by 100. Name this data set as 'CaBi.pct2'

CaBi.pct2 = ddply(CaBi.pct1, 
                  "No.Months",                            
                  transform,                          
                  Percent = New.Member.Count / Per.Month * 100)

View(CaBi.pct2)

# 19. Graph 'CaBi.pct2' as a stacked area chart with x as 'No.Months', y as
#     'Percent', and fill as 'Municipality'

ggplot(CaBi.pct2, 
       aes(x = No.Months, 
           y = Percent, 
           fill = Municipality)) + 
  geom_area()

# 20. Adjust the scales of the percentage area plot, so the x axis displays
#     every 5 marks, and the y axis displays every 10 marks.

ggplot(CaBi.pct2, 
       aes(x = No.Months, 
           y = Percent, 
           fill = Municipality)) + 
  geom_area() + 
  scale_x_continuous(breaks = seq(0, 56, by = 5)) +  
  scale_y_continuous(breaks = seq(0, 100, by = 10))  

# 21. Add in black lines with 0.25 size that separate each section and set
#     the transparency to 0.5 (hint: this is in the geom_area() function)

ggplot(CaBi.pct2, 
       aes(x = No.Months, 
           y = Percent, 
           fill = Municipality)) + 
  geom_area(color = "black", size = 0.25, alpha = 0.5) + 
  scale_x_continuous(breaks = seq(0, 56, by = 5)) +  
  scale_y_continuous(breaks = seq(0, 100, by = 10))  

# 22. Add in the preset theme, theme_minimal().

ggplot(CaBi.pct2, 
       aes(x = No.Months, 
           y = Percent, 
           fill = Municipality)) + 
  geom_area(color = "black", size = 0.25, alpha = 0.5) + 
  scale_x_continuous(breaks = seq(0, 56, by = 5)) +  
  scale_y_continuous(breaks = seq(0, 100, by = 10)) +
  theme_minimal()

# 23. Label the x axis as "Number of Months", the y axis as "Percent of
#     New Annual Members", and the title as "New Annual Bikeshare Members
#     from Sep 2010 - Mar 2015"

ggplot(CaBi.pct2, 
       aes(x = No.Months, 
           y = Percent, 
           fill = Municipality)) + 
  geom_area(color = "black", size = 0.25, alpha = 0.5) + 
  scale_x_continuous(breaks = seq(0, 56, by = 5)) +  
  scale_y_continuous(breaks = seq(0, 100, by = 10)) +
  theme_minimal() +
labs(y = "Percent of New Annual Members",
     x = "Number of Months",
     title = "New Annual Bikeshare Members from Sep 2010 - Mar 2015")

# 24. Adjust the color palette to "Spectral"

ggplot(CaBi.pct2, 
       aes(x = No.Months, 
           y = Percent, 
           fill = Municipality)) + 
  geom_area(color = "black", size = 0.25, alpha = 0.5) + 
  scale_x_continuous(breaks = seq(0, 56, by = 5)) +  
  scale_y_continuous(breaks = seq(0, 100, by = 10)) +
  theme_minimal() +
  labs(y = "Percent of New Annual Members",
       x = "Number of Months",
       title = "New Annual Bikeshare Members from Sep 2010 - Mar 2015") +
  scale_fill_brewer(palette = "Spectral")

# 25. Facet wrap the graph by 'Municipality' and adjust the x axis scale
#     to count off every 10 tick marks.

ggplot(CaBi.pct2, 
       aes(x = No.Months, 
           y = Percent, 
           fill = Municipality)) + 
  geom_area(color = "black", size = 0.25, alpha = 0.75) + 
  scale_x_continuous(breaks = seq(0, 56, by = 10)) +  
  scale_y_continuous(breaks = seq(0, 100, by = 10)) +
  theme_minimal() +
  labs(y = "Percent of New Annual Members",
       x = "Number of Months",
       title = "New Annual Bikeshare Members from Sep 2010 - Mar 2015") +
  scale_fill_brewer(palette = "Spectral") +
  facet_wrap(~Municipality)

# 26. Set your working directory and save the latest graph as a png file labeled
#     "Bikeshare_data.png"


# Set the directory

setwd("~/Desktop")

# Use ggsave to save the last plot you created

ggsave("Bikeshare_data.png", width = 10, height = 5.62, units = "in")

